Flask-GoogleLogin
-----------------
Flask-GoogleLogin extends Flask-Login to use Google's OAuth2 authorization

Links
`````
* `Documentation <http://packages.python.org/Flask-GoogleLogin>`_
* `Development version <https://github.com/marksteve/flask-googlelogin>`_
* `Changelog <https://github.com/insynchq/flask-googlelogin/blob/master/CHANGELOG.rst>`_
